API Reference
=============

This part of the documentation details the complete ``BioSPPy`` API.

Packages
--------

.. toctree::
   :maxdepth: 1

   biosppy.signals

Modules
-------

.. contents::
   :local:

.. automodule:: biosppy.biometrics
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.clustering
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.metrics
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.plotting
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.storage
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.timing
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: biosppy.utils
    :members:
    :undoc-members:
    :show-inheritance:
